AudioSpectrumValue class

Constructors

AudioSpectrumValue({required List<int> levels, required List<int> peakLevels, required List<int> meanLevels})
AudioSpectrumValue.empty()

Properties

hashCode → int
The hash code for this object.
no setterinherited
levels → List<int>
final
meanLevels → List<int>
final
peakLevels → List<int>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited